@@ -11,7 +11,7 @@ no warnings qw( void once uninitialized );
 	our @ISA = 'Exporter';
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.002';
+	our $VERSION   = '0.003';
 	our @EXPORT    = qw( boolean );
 	our (%LANG, @LANG);
 	our @BASELANG  = qw( zh en es hi ru ar pt bn fr ms de ja );
@@ -59,7 +59,7 @@ no warnings qw( void once uninitialized );
 	package Lingua::Boolean::Tiny::BASE;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.002';
+	our $VERSION   = '0.003';
 	
 	# Versions of ~~ and fc for legacy Perls...
 	use if $] >= 5.016, feature => 'fc';
@@ -149,16 +149,12 @@ no warnings qw( void once uninitialized );
 	package Lingua::Boolean::Tiny::Union;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.002';
+	our $VERSION   = '0.003';
 	
 	sub new
 	{
 		my $class = shift;
-		bless [
-			map  $_->new,
-			grep defined,
-			map  $Lingua::Boolean::Tiny::LANG{lc $_}, @_
-		] => $class;
+		bless [ grep defined, map "Lingua::Boolean::Tiny"->new_strict($_), @_ ] => $class;
 	}
 	
 	sub boolean
@@ -323,7 +319,8 @@ order is significant - in case of ambiguities, the earlier language wins.
 
 =item C<< Lingua::Boolean::Tiny->new() >>
 
-Construct a new object supporting the union of all supported languages.
+Construct a new object supporting the union of the twelve main supported
+languages.
 
 =item C<< Lingua::Boolean::Tiny->new_strict($lang) >>
 
